Coverage for api/info.py: 0%

# Coverage for api/info.py : 0%

## 4 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 import datetime

2

3 info = r"""

4 _____ _

5 / ____| |

6 | (___ | |__ ___ _ __ _ _ ___

7 \___ \| '_ \ / _ \| '_ \| | | |/ _ \

8 ____) | | | | (_) | |_) | |_| | (_) |

9 |_____/|_| |_|\___/| .__/ \__, |\___/

10 | | __/ |

11 |_| |___/

12 Copyright {year}

13""".format(

14 year=datetime.datetime.now().year

15)

16

17

18 def printinfo():

19 """

20 prints Shopyo copyright in ASCII art font

21 """

22 print(info)